# Changelog

## [0.0.16a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a5) (2024-01-08)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a4...0.0.16a5)

**Implemented enhancements:**

- feat/ocp\_voc\_match [\#172](https://github.com/OpenVoiceOS/OVOS-workshop/pull/172) ([NeonJarbas](https://github.com/NeonJarbas))

## [0.0.16a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a4) (2024-01-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a3...0.0.16a4)

**Fixed bugs:**

- When a skill reload fails then try and clean up [\#173](https://github.com/OpenVoiceOS/OVOS-workshop/pull/173) ([lbt](https://github.com/lbt))

## [0.0.16a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a3) (2024-01-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a2...0.0.16a3)

**Fixed bugs:**

- FallbackSkill `__new__()` fails for FallbackSkillV1 [\#170](https://github.com/OpenVoiceOS/OVOS-workshop/issues/170)
- Just publish the skill\_id without the extra ":" [\#171](https://github.com/OpenVoiceOS/OVOS-workshop/pull/171) ([lbt](https://github.com/lbt))

## [0.0.16a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a2) (2023-12-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a1...0.0.16a2)

**Fixed bugs:**

- fix/loading\_failure\_logs\_even\_if\_loaded [\#168](https://github.com/OpenVoiceOS/OVOS-workshop/pull/168) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a1) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15...0.0.16a1)

**Merged pull requests:**

- packaging/update\_imports [\#167](https://github.com/OpenVoiceOS/OVOS-workshop/pull/167) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
